==> kernel-0.9.1.5.1-sources.jar: voxeet/com/sdk/events/success/ResumeConference.java <==
package voxeet.com.sdk.events.success;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;

import java.util.List;

import voxeet.com.sdk.models.impl.DefaultParticipant;

/**
 * Created by RomainB on 5/25/16.
 */
@JsonIgnoreProperties(ignoreUnknown = true)
public class ResumeConference {

    private List<DefaultParticipant> participants;

    private String conferenceAlias;

    private String conferenceId;

    private String quality;

    private String recordingStatus;

    private String recordingUser;

    private long startRecordTimestamp;

    private String conferenceType;

    public List<DefaultParticipant> getParticipants() {
        return participants;
    }

    public void setParticipants(List<DefaultParticipant> participants) {
        this.participants = participants;
    }

    public String getQuality() {
        return quality;
    }

    public void setQuality(String quality) {
        this.quality = quality;
    }

    public String getRecordingStatus() {
        return recordingStatus;
    }

    public void setRecordingStatus(String recordingStatus) {
        this.recordingStatus = recordingStatus;
    }

    public String getRecordingUser() {
        return recordingUser;
    }

    public void setRecordingUser(String recordingUser) {
        this.recordingUser = recordingUser;
    }

    public long getStartRecordTimestamp() {
        return startRecordTimestamp;
    }

    public void setStartRecordTimestamp(long startRecordTimestamp) {
        this.startRecordTimestamp = startRecordTimestamp;
    }

    public String getConferenceType() {
        return conferenceType;
    }

    public void setConferenceType(String conferenceType) {
        this.conferenceType = conferenceType;
    }

    public String getConferenceId() {
        return conferenceId;
    }

    public String getConferenceAlias() {
        return conferenceAlias;
    }
}

==> kernel-2.0.2-sources.jar: voxeet/com/sdk/events/success/ResumeConference.java <==
package voxeet.com.sdk.events.success;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;

import java.util.List;

import voxeet.com.sdk.models.OfferCandidate;
import voxeet.com.sdk.models.OfferDescription;
import voxeet.com.sdk.models.impl.DefaultParticipant;

/**
 * Created by RomainB on 5/25/16.
 */
@JsonIgnoreProperties(ignoreUnknown = true)
public class ResumeConference {

    private List<DefaultParticipant> participants;

    private String conferenceAlias;

    private String conferenceId;

    private String quality;

    private String recordingStatus;

    private String recordingUser;

    private long startRecordTimestamp;

    private String conferenceType;

    private OfferDescription description;

    private List<OfferCandidate> candidates;

    public List<DefaultParticipant> getParticipants() {
        return participants;
    }

    public void setParticipants(List<DefaultParticipant> participants) {
        this.participants = participants;
    }

    public String getQuality() {
        return quality;
    }

    public void setQuality(String quality) {
        this.quality = quality;
    }

    public String getRecordingStatus() {
        return recordingStatus;
    }

    public void setRecordingStatus(String recordingStatus) {
        this.recordingStatus = recordingStatus;
    }

    public String getRecordingUser() {
        return recordingUser;
    }

    public void setRecordingUser(String recordingUser) {
        this.recordingUser = recordingUser;
    }

    public long getStartRecordTimestamp() {
        return startRecordTimestamp;
    }

    public void setStartRecordTimestamp(long startRecordTimestamp) {
        this.startRecordTimestamp = startRecordTimestamp;
    }

    public String getConferenceType() {
        return conferenceType;
    }

    public void setConferenceType(String conferenceType) {
        this.conferenceType = conferenceType;
    }

    public String getConferenceId() {
        return conferenceId;
    }

    public String getConferenceAlias() {
        return conferenceAlias;
    }

    public OfferDescription getDescription() {
        return description;
    }

    public void setDescription(OfferDescription description) {
        this.description = description;
    }

    public List<OfferCandidate> getCandidates() {
        return candidates;
    }

    public void setCandidates(List<OfferCandidate> candidates) {
        this.candidates = candidates;
    }
}
